(function (QUnit,sinon,videojs) {
'use strict';

QUnit = QUnit && QUnit.hasOwnProperty('default') ? QUnit['default'] : QUnit;
sinon = sinon && sinon.hasOwnProperty('default') ? sinon['default'] : sinon;
videojs = videojs && videojs.hasOwnProperty('default') ? videojs['default'] : videojs;

var commonjsGlobal = typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

var empty = {};


var empty$1 = Object.freeze({
	default: empty
});

var minDoc = ( empty$1 && empty ) || empty$1;

var topLevel = typeof commonjsGlobal !== 'undefined' ? commonjsGlobal :
    typeof window !== 'undefined' ? window : {};


var doccy;

if (typeof document !== 'undefined') {
    doccy = document;
} else {
    doccy = topLevel['__GLOBAL_DOCUMENT_CACHE@4'];

    if (!doccy) {
        doccy = topLevel['__GLOBAL_DOCUMENT_CACHE@4'] = minDoc;
    }
}

var document_1 = doccy;

var version = "1.0.0";

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) {
  return typeof obj;
} : function (obj) {
  return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
};











var classCallCheck = function (instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
};











var inherits = function (subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      enumerable: false,
      writable: true,
      configurable: true
    }
  });
  if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
};











var possibleConstructorReturn = function (self, call) {
  if (!self) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return call && (typeof call === "object" || typeof call === "function") ? call : self;
};

var Plugin = videojs.getPlugin('plugin');

var ConstantTimeupdatePlugin = function (_Plugin) {
	inherits(ConstantTimeupdatePlugin, _Plugin);

	function ConstantTimeupdatePlugin(player, options) {
		classCallCheck(this, ConstantTimeupdatePlugin);

		var _this = possibleConstructorReturn(this, _Plugin.call(this, player, options));

		var interval = options && options.interval || 1000;
		var roundFn = options && options.roundFn || Math.round;
		player.on('play', function () {
			clearInterval(_this.timeHandler);
			var currentTime = roundFn(player.currentTime());
			_this.timeHandler = setInterval(function () {
				currentTime = roundFn(player.currentTime());
				if (_this.lastTime !== currentTime) {
					player.trigger('constant-timeupdate', currentTime);
					_this.lastTime = currentTime;
				}
			}, interval);
			if (_this.lastTime !== currentTime) {
				player.trigger('constant-timeupdate', currentTime);
				_this.lastTime = currentTime;
			}
		});
		player.on('pause', function () {
			clearInterval(_this.timeHandler);
		});
		player.on('ended', function () {
			clearInterval(_this.timeHandler);
		});
		return _this;
	}

	return ConstantTimeupdatePlugin;
}(Plugin);

ConstantTimeupdatePlugin.VERSION = version;

var registerPlugin = videojs.registerPlugin || videojs.plugin;

registerPlugin('constantTimeupdate', ConstantTimeupdatePlugin);

var Player = videojs.getComponent('Player');

QUnit.test('the environment is sane', function (assert) {
  assert.strictEqual(_typeof(Array.isArray), 'function', 'es5 exists');
  assert.strictEqual(typeof sinon === 'undefined' ? 'undefined' : _typeof(sinon), 'object', 'sinon exists');
  assert.strictEqual(typeof videojs === 'undefined' ? 'undefined' : _typeof(videojs), 'function', 'videojs exists');
  assert.strictEqual(typeof ConstantTimeupdatePlugin === 'undefined' ? 'undefined' : _typeof(ConstantTimeupdatePlugin), 'function', 'plugin is a function');
});

QUnit.module('videojs-constant-timeupdate', {
  beforeEach: function beforeEach() {

    // Mock the environment's timers because certain things - particularly
    // player readiness - are asynchronous in video.js 5. This MUST come
    // before any player is created; otherwise, timers could get created
    // with the actual timer methods!
    this.clock = sinon.useFakeTimers();

    this.fixture = document_1.getElementById('qunit-fixture');
    this.video = document_1.createElement('video');
    this.fixture.appendChild(this.video);
    this.player = videojs(this.video);
  },
  afterEach: function afterEach() {
    this.player.dispose();
    this.clock.restore();
  }
});

QUnit.test('registers itself with video.js', function (assert) {
  assert.expect(2);

  assert.strictEqual(_typeof(Player.prototype.constantTimeupdate), 'function', 'videojs-constant-timeupdate plugin was registered');

  this.player.constantTimeupdate();

  // Tick the clock forward enough to trigger the player to be "ready".
  this.clock.tick(1);

  assert.ok(this.player.hasClass('vjs-constant-timeupdate'), 'the plugin adds a class to the player');
});

}(QUnit,sinon,videojs));
